@@ -44,7 +44,7 @@ using namespace Baloo;
 
 SearchModule::SearchModule(QObject* parent, const QList<QVariant>&)
     : KDEDModule(parent)
-    , m_dirNotify(0)
+    , m_dirNotify(nullptr)
 {
     QTimer::singleShot(0, this, SLOT(init()));
 }
@@ -53,19 +53,19 @@ void SearchModule::init()
 {
     m_dirNotify = new org::kde::KDirNotify(QString(), QString(),
                                            QDBusConnection::sessionBus(), this);
-    connect(m_dirNotify, SIGNAL(enteredDirectory(QString)),
-            this, SLOT(registerSearchUrl(QString)));
-    connect(m_dirNotify, SIGNAL(leftDirectory(QString)),
-            this, SLOT(unregisterSearchUrl(QString)));
+    connect(m_dirNotify, &OrgKdeKDirNotifyInterface::enteredDirectory,
+            this, &SearchModule::registerSearchUrl);
+    connect(m_dirNotify, &OrgKdeKDirNotifyInterface::leftDirectory,
+            this, &SearchModule::unregisterSearchUrl);
 
 
     // FIXME: Listen to changes from Baloo!!
     // Listen to dbChanged
     QDBusConnection con = QDBusConnection::sessionBus();
-    con.connect(QString(), QLatin1String("/files"), QLatin1String("org.kde.baloo"),
-                QLatin1String("updated"), this, SLOT(slotBalooFileDbChanged()));
-    con.connect(QString(), QLatin1String("/files"), QLatin1String("org.kde"),
-                QLatin1String("changed"), this, SLOT(slotFileMetaDataChanged(QStringList)));
+    con.connect(QString(), QStringLiteral("/files"), QStringLiteral("org.kde.baloo"),
+                QStringLiteral("updated"), this, SLOT(slotBalooFileDbChanged()));
+    con.connect(QString(), QStringLiteral("/files"), QStringLiteral("org.kde"),
+                QStringLiteral("changed"), this, SLOT(slotFileMetaDataChanged(QStringList)));
 }
 
 
@@ -86,7 +86,7 @@ void SearchModule::unregisterSearchUrl(const QString& urlString)
 void SearchModule::slotBalooFileDbChanged()
 {
     qDebug() << m_searchUrls;
-    for (const QUrl& dirUrl : m_searchUrls) {
+    for (const QUrl& dirUrl : qAsConst(m_searchUrls)) {
         org::kde::KDirNotify::emitFilesAdded(dirUrl);
     }
 }
@@ -103,6 +103,8 @@ void SearchModule::slotFileMetaDataChanged(const QStringList& list)
     slotBalooFileDbChanged();
 }
 
-K_PLUGIN_FACTORY(Factory, registerPlugin<SearchModule>();)
+K_PLUGIN_FACTORY_WITH_JSON(Factory,
+                           "baloosearchmodule.json",
+                           registerPlugin<SearchModule>();)
 
 #include "baloosearchmodule.moc"
